# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2016-10-25 04:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Email',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('when', models.DateTimeField(auto_now_add=True, verbose_name='when')),
                ('whom', models.CharField(max_length=254, verbose_name='whom')),
                ('subject', models.CharField(max_length=254, verbose_name='subject')),
                ('body', models.TextField(verbose_name='body')),
                ('status', models.CharField(max_length=254, verbose_name='status')),
            ],
            options={
                'verbose_name': 'email',
                'verbose_name_plural': 'emails',
            },
        ),
    ]
